==> blowing-bubbles-0.1.0-sources.jar: net/nml/bubble/block/BubbleBlock.java <==
package net.nml.bubble.block;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1767;
import net.minecraft.class_1922;
import net.minecraft.class_2338;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3726;
import net.minecraft.class_4275;
import net.minecraft.class_8923;
import net.nml.bubble.PopParticleEffect;

public class BubbleBlock extends class_8923 implements class_4275 {
	public static final MapCodec<BubbleBlock> field_46366 = RecordCodecBuilder.mapCodec(
		instance -> instance.group(class_1767.field_41600.fieldOf("color").forGetter(BubbleBlock::method_10622), method_54096())
			.apply(instance, BubbleBlock::new)
	);
	private final class_1767 color;

    // public static final BooleanProperty NORTH = Properties.NORTH;
	// public static final BooleanProperty EAST = Properties.EAST;
	// public static final BooleanProperty SOUTH = Properties.SOUTH;
	// public static final BooleanProperty WEST = Properties.WEST;
	// public static final BooleanProperty UP = Properties.UP;
	// public static final BooleanProperty DOWN = Properties.DOWN;

    @Override
    protected MapCodec<BubbleBlock> method_53969() {
        return field_46366;
    }
    
    public BubbleBlock(class_1767 color, class_2251 settings) {
        super(settings);
		this.color = color;
		// this.setDefaultState(this.stateManager.getDefaultState().with(NORTH, false).with(SOUTH, false).with(EAST, false).with(WEST, false).with(UP, false).with(DOWN, false));
    }

	@Override
	protected void method_66388(class_2680 state, class_3218 world, class_2338 pos, boolean moved) {
		super.method_66388(state, world, pos, moved);
		world.method_65096(new PopParticleEffect(this.method_10622().method_7787(), 1.7f),
			pos.method_10263() + 0.5, pos.method_10264() + 0.5, pos.method_10260() + 0.5,
			1, 0, 0, 0, 0);
	}

    // @Override
    // protected void appendProperties(StateManager.Builder<Block, BlockState> builder) {
    //     builder.add(NORTH, SOUTH, EAST, WEST, UP, DOWN);
    // }

    // @Override
    // public BlockState getPlacementState(ItemPlacementContext ctx) {
    //     return updateConnections(ctx.getWorld(), ctx.getBlockPos(), getDefaultState());
    // }

	// @Override
	// protected BlockState getStateForNeighborUpdate(BlockState state, WorldView world, ScheduledTickView tickView,
	// 		BlockPos pos, Direction direction, BlockPos neighborPos, BlockState neighborState, Random random) {
	// 	return updateConnections(world, pos, state);
	// }

    // private BlockState updateConnections(WorldView world, BlockPos pos, BlockState state) {
    //     boolean n = connects(world, pos.north());
    //     boolean s = connects(world, pos.south());
    //     boolean e = connects(world, pos.east());
    //     boolean w = connects(world, pos.west());
	// 	boolean u = connects(world, pos.up());
	// 	boolean d = connects(world, pos.down());

    //     int connectionsAllowed = 4;
    //     n = n && (connectionsAllowed-- > 0);
    //     s = s && (connectionsAllowed-- > 0);
    //     e = e && (connectionsAllowed-- > 0);
    //     w = w && (connectionsAllowed-- > 0);
	// 	u = u && (connectionsAllowed-- > 0);
	// 	d = d && (connectionsAllowed-- > 0);

    //     return state.with(NORTH, n).with(SOUTH, s).with(EAST, e).with(WEST, w).with(UP, u).with(DOWN, d);
    // }

    // private boolean connects(WorldView world, BlockPos other) {
	// 	BlockState state = world.getBlockState(other);
	// 	if (state.getBlock() instanceof BubbleBlock bubbleBlock && bubbleBlock.getColor() == this.getColor()) {
	// 		int connectionCount = 0;
	// 		if (state.get(BubbleBlock.NORTH)) connectionCount++;
	// 		if (state.get(BubbleBlock.SOUTH)) connectionCount++;
	// 		if (state.get(BubbleBlock.EAST)) connectionCount++;
	// 		if (state.get(BubbleBlock.WEST)) connectionCount++;
	// 		if (state.get(BubbleBlock.UP)) connectionCount++;
	// 		if (state.get(BubbleBlock.DOWN)) connectionCount++;
	// 		return connectionCount <= 4;
	// 	}
	// 	return false;
    // }

	@Override
	public class_1767 method_10622() {
		return this.color;
	}
	
    @Override
    protected class_265 method_9549(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return class_259.method_1073();
    }
}

==> blowing-bubbles-1.0.3-sources.jar: net/nml/bubble/block/BubbleBlock.java <==
package net.nml.bubble.block;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1767;
import net.minecraft.class_1922;
import net.minecraft.class_2338;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3726;
import net.minecraft.class_4275;
import net.minecraft.class_8923;
import net.nml.bubble.PopParticleEffect;

public class BubbleBlock extends class_8923 implements class_4275 {
	public static final MapCodec<BubbleBlock> field_46366 = RecordCodecBuilder.mapCodec(
		instance -> instance.group(class_1767.field_41600.fieldOf("color").forGetter(BubbleBlock::method_10622), method_54096())
			.apply(instance, BubbleBlock::new)
	);
	private final class_1767 color;

    // public static final BooleanProperty NORTH = Properties.NORTH;
	// public static final BooleanProperty EAST = Properties.EAST;
	// public static final BooleanProperty SOUTH = Properties.SOUTH;
	// public static final BooleanProperty WEST = Properties.WEST;
	// public static final BooleanProperty UP = Properties.UP;
	// public static final BooleanProperty DOWN = Properties.DOWN;

    @Override
    protected MapCodec<BubbleBlock> method_53969() {
        return field_46366;
    }
    
    public BubbleBlock(class_1767 color, class_2251 settings) {
        super(settings);
		this.color = color;
		// this.setDefaultState(this.stateManager.getDefaultState().with(NORTH, false).with(SOUTH, false).with(EAST, false).with(WEST, false).with(UP, false).with(DOWN, false));
    }

	@Override
	protected void method_66388(class_2680 state, class_3218 world, class_2338 pos, boolean moved) {
		super.method_66388(state, world, pos, moved);
		world.method_65096(new PopParticleEffect(this.method_10622().method_7787(), 1.7f),
			pos.method_10263() + 0.5, pos.method_10264() + 0.5, pos.method_10260() + 0.5,
			1, 0, 0, 0, 0);
	}

    // @Override
    // protected void appendProperties(StateManager.Builder<Block, BlockState> builder) {
    //     builder.add(NORTH, SOUTH, EAST, WEST, UP, DOWN);
    // }

    // @Override
    // public BlockState getPlacementState(ItemPlacementContext ctx) {
    //     return updateConnections(ctx.getEntityWorld(), ctx.getBlockPos(), getDefaultState());
    // }

	// @Override
	// protected BlockState getStateForNeighborUpdate(BlockState state, WorldView world, ScheduledTickView tickView,
	// 		BlockPos pos, Direction direction, BlockPos neighborPos, BlockState neighborState, Random random) {
	// 	return updateConnections(world, pos, state);
	// }

    // private BlockState updateConnections(WorldView world, BlockPos pos, BlockState state) {
    //     boolean n = connects(world, pos.north());
    //     boolean s = connects(world, pos.south());
    //     boolean e = connects(world, pos.east());
    //     boolean w = connects(world, pos.west());
	// 	boolean u = connects(world, pos.up());
	// 	boolean d = connects(world, pos.down());

    //     int connectionsAllowed = 4;
    //     n = n && (connectionsAllowed-- > 0);
    //     s = s && (connectionsAllowed-- > 0);
    //     e = e && (connectionsAllowed-- > 0);
    //     w = w && (connectionsAllowed-- > 0);
	// 	u = u && (connectionsAllowed-- > 0);
	// 	d = d && (connectionsAllowed-- > 0);

    //     return state.with(NORTH, n).with(SOUTH, s).with(EAST, e).with(WEST, w).with(UP, u).with(DOWN, d);
    // }

    // private boolean connects(WorldView world, BlockPos other) {
	// 	BlockState state = world.getBlockState(other);
	// 	if (state.getBlock() instanceof BubbleBlock bubbleBlock && bubbleBlock.getColor() == this.getColor()) {
	// 		int connectionCount = 0;
	// 		if (state.get(BubbleBlock.NORTH)) connectionCount++;
	// 		if (state.get(BubbleBlock.SOUTH)) connectionCount++;
	// 		if (state.get(BubbleBlock.EAST)) connectionCount++;
	// 		if (state.get(BubbleBlock.WEST)) connectionCount++;
	// 		if (state.get(BubbleBlock.UP)) connectionCount++;
	// 		if (state.get(BubbleBlock.DOWN)) connectionCount++;
	// 		return connectionCount <= 4;
	// 	}
	// 	return false;
    // }

	@Override
	public class_1767 method_10622() {
		return this.color;
	}
	
    @Override
    protected class_265 method_9549(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return class_259.method_1073();
    }
}
